Documentation
¶
Rendered for js/wasm
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type FS ¶
type FS struct {
// contains filtered or unexported fields
}
FS is a virtual filesystem that triggers browser downloads on file close. Files written to this filesystem don't persist - instead, when closed, their contents are downloaded in the browser with the filename.
Click to show internal directories.
Click to hide internal directories.